Stan Math Library: stan/math/prim/scal/fun/rising_factorial.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

rising_factorial.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_RISING_FACTORIAL_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_RISING_FACTORIAL_HPP
3
4 #include <stan/math/prim/scal/fun/log_rising_factorial.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9
52 template<typename T1, typename T2>
53 inline typename boost::math::tools::promote_args<T1, T2>::type
54 rising_factorial(const T1 x, const T2 n) {
55 using std::exp;
56 return exp(stan::math::log_rising_factorial(x, n));
57 }
58
59 }
60 }
61
62 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
log_rising_factorial.hpp
stan::math::log_rising_factorial
fvar< T > log_rising_factorial(const fvar< T > &x, const fvar< T > &n)
Definition: log_rising_factorial.hpp:16
stan::math::rising_factorial
fvar< T > rising_factorial(const fvar< T > &x, const fvar< T > &n)
Definition: rising_factorial.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.